import sys
print(f"程序包含模板：{sys.modules}")
print(f"程序程序路径：{sys.path}")
print(f"程序运行平台：{sys.platform}")
print(f"程序默认编码：{sys.getdefaultencoding()}")

def get_information():
    return "ckh2.handsome.com"



from setuptools import setup,find_packages
setup(
name="dwy",
version="0.1",
author="dwy",
packages = find_packages("src"),
package_dir = {"":"src"},
description="邓文怡",
package_data = {
    "":[".txt",".info","*.properties",".py"],
    "":["data/*.*"],
},
exclude = ["*.test","*.test.*","test.*","test"]
)
